from .articles import Articles
from .clients import Clients
from .comandes import Comandes
from .pobles import Pobles
from .provincies import Provincies
from .portals_web import PortalsWeb
from .regularitzacions import Regularitzacions
from .usuaris import Usuaris
from .wms import Wms
